@@ -228,6 +228,41 @@ static inline long jent_ncpu(void)
 #endif
 }
 
+static inline uint32_t jent_cache_size_roundup(void)
+{
+#ifdef __linux__
+	long l1 = sysconf(_SC_LEVEL1_DCACHE_SIZE);
+	long l2 = sysconf(_SC_LEVEL2_CACHE_SIZE);
+	long l3 = sysconf(_SC_LEVEL3_CACHE_SIZE);
+	uint32_t cache_size = 0;
+
+	/* Cache size reported by system */
+	if (l1 > 0)
+		cache_size += (uint32_t)l1;
+	if (l2 > 0)
+		cache_size += (uint32_t)l2;
+	if (l3 > 0)
+		cache_size += (uint32_t)l3;
+
+	/* Force the output_size to be of the form (bounding_power_of_2 - 1). */
+	cache_size |= (cache_size >> 1);
+	cache_size |= (cache_size >> 2);
+	cache_size |= (cache_size >> 4);
+	cache_size |= (cache_size >> 8);
+	cache_size |= (cache_size >> 16);
+
+	if (cache_size == 0)
+		return 0;
+
+	/* Make the output_size the smallest power of 2 strictly greater than cache_size. */
+	cache_size++;
+
+	return cache_size;
+#else
+	return 0;
+#endif
+}
+
 static inline void jent_yield(void)
 {
 	sched_yield();
